@@ -190,6 +190,10 @@ QEMU_CREATE_SCHEMA = {
             "description": "Replicate the network connection state for links in Qemu",
             "type": ["boolean", "null"],
         },
+        "tpm": {
+            "description": "Enable the Trusted Platform Module (TPM) in Qemu",
+            "type": ["boolean", "null"],
+        },
         "create_config_disk": {
             "description": "Automatically create a config disk on HDD disk interface (secondary slave)",
             "type": ["boolean", "null"],
@@ -384,6 +388,10 @@ QEMU_UPDATE_SCHEMA = {
             "description": "Replicate the network connection state for links in Qemu",
             "type": ["boolean", "null"],
         },
+        "tpm": {
+            "description": "Enable the Trusted Platform Module (TPM) in Qemu",
+            "type": ["boolean", "null"],
+        },
         "create_config_disk": {
             "description": "Automatically create a config disk on HDD disk interface (secondary slave)",
             "type": ["boolean", "null"],
@@ -591,6 +599,10 @@ QEMU_OBJECT_SCHEMA = {
             "description": "Replicate the network connection state for links in Qemu",
             "type": "boolean",
         },
+        "tpm": {
+            "description": "Enable the Trusted Platform Module (TPM) in Qemu",
+            "type": "boolean",
+        },
         "create_config_disk": {
             "description": "Automatically create a config disk on HDD disk interface (secondary slave)",
             "type": ["boolean", "null"],
@@ -665,6 +677,7 @@ QEMU_OBJECT_SCHEMA = {
                  "kernel_command_line",
                  "legacy_networking",
                  "replicate_network_connection_state",
+                 "tpm",
                  "create_config_disk",
                  "on_close",
                  "cpu_throttling",
